# Overview

This charm installs various hardware system monitoring tools and configures
Nagios NRPE checks. It will only work for bare-metal installations on specific
hardware.

Currently supported hardware is:

 * Dell: LSI Logic MegaRAID SAS-3 3108 [Invader] (Broadcom MegaCLI utility)
 * Supermicro: LSI SAS3008 RAID card with sas3ircu (Broadcoam's SAS3IRCU_P16)
 * Huawei: LSI SAS2308 RAID card with sas2ircu (Huawei FusionServer Tools
   InfoCollect)
 * SSD cards: Intel's  PCIe Data Center SSD, Samsung's NVMe controllers for
   SM961/PM961 and 172Xa/172Xb.

Hardware-independent tools:

 * Linux software RAID (mdadm)
 * IPMI as implemented by freeipmi (enable_ipmi config option is enabled by
   default)

In the backlog, hp-health logic still needs to be backported to support
Hewlett-Packard equipment (HP Smart Array Controllers and MSA Controllers with
hpacucli, hpssacli, ssacli).

Furthermore, other hardware in the roadmap is:

  * Huawei's ES3000 V2 PCIe SSD Card with hio_info (Huawei ES3000 V2 Driver)
  * S.M.A.R.T. Monitoring tool (smartctl)

# Usage

```
juju deploy ubuntu
juju deploy hw-health
juju deploy nrpe
juju add-relation ubuntu nrpe
juju add-relation ubuntu hw-health
juju add-relation hw-health nrpe
```

Charmstore version already ships a resource. However, a new resource can be
attached:

 * Option 1: `juju deploy hw-health --resource tools=/tmp/zipfile.zip`
 * Option 2: `juju attach-resource hw-health tools=/tmp/zipfile.zip`

In both cases format of zipfile.zip must be one of the following:
```
zip /tmp/zipfile.zip megacli sas2ircu sas3ircu
zip /tmp/zipfile.zip megacli
etc.
```

## Known Limitations and Issues

Charm only install method is via Juju resources. There are plans to support
snaps but snapstore only supports strictly confined snaps. Hardware monitoring
tools need special permissions that are under development.

See https://forum.snapcraft.io/t/request-for-classic-confinement-sas2ircu/9023

"tools" resource needs to be attached in ZIP format, and hardware monitoring
tool(s) need to be on the first level of the archive tree.

# Building the tools.zip resource

In order to build the tools.zip resource it is necessary to source the binaries
from the respective vendor support pages.

For example:
[megacli](https://docs.broadcom.com/docs/12351586)/
[sas3ircu](https://docs.broadcom.com/docs/SAS3IRCU_P16.zip)/
[sas2ircu](https://docs.broadcom.com/docs/12351735)

You will then have to extract, rename, and compress the binaries to obtain the
following structure:

```
$ zipinfo tools.zip
Archive:  tools.zip
Zip file size: 1204457 bytes, number of entries: 3
-rwxr-xr-x  3.0 unx  2720320 bx defN 19-Jan-16 11:31 megacli
-rwxrwxr-x  3.0 unx   559164 bx defN 19-Jan-16 11:31 sas2ircu
-rwxrwxr-x  3.0 unx   562560 bx defN 19-Jan-16 11:31 sas3ircu
3 files, 3842044 bytes uncompressed, 1204005 bytes compressed:  68.7%
```

# Configuration

Manufacturer option needs to be left in auto mode.

# Contact Information

Please contact the Nagios charmers via the "Submit a bug" link.

## Upstream Project Name

 * Website: https://launchpad.net/hw-health-charm
 * Bug tracker: https://bugs.launchpad.net/hw-health-charm
