#!/usr/bin/env python3
# -*- coding: us-ascii -*-

import os
import subprocess
import sys

CHECK_IPMI_PID = '/var/run/nagios/check_ipmi_sensors.pid'
OUTPUT_FILE = '/var/lib/nagios/ipmi_sensors.out'
TMP_OUTPUT_FILE = OUTPUT_FILE + '.tmp'
CMD = '/usr/local/lib/nagios/plugins/check_ipmi_sensor'
NAGIOS_ERRORS = {
    1: 'WARNING',
    2: 'CRITICAL',
    3: 'UNKNOWN',
}


def gather_metrics():
    # a child is already running
    if os.path.exists(CHECK_IPMI_PID):
        return

    try:
        with open(CHECK_IPMI_PID, 'w') as fd:
            fd.write(str(os.getpid()))

        cmdline = [CMD]
        if len(sys.argv) > 1:
            cmdline.extend(sys.argv[1:])

        output = subprocess.check_output(cmdline)
        with open(TMP_OUTPUT_FILE, 'w') as fd:
            fd.write(output.decode(errors='ignore'))
        os.rename(TMP_OUTPUT_FILE, OUTPUT_FILE)
    except subprocess.CalledProcessError as error:
        output = error.stdout.decode(errors='ignore')
        with open(TMP_OUTPUT_FILE, 'w') as fd:
            fd.write('{}: {}'.format(NAGIOS_ERRORS[error.returncode], output))
        os.rename(TMP_OUTPUT_FILE, OUTPUT_FILE)
    except PermissionError as error:
        with (OUTPUT_FILE, 'w') as fd:
            fd.write('UNKNOWN: {}'.format(error))

    # remove pid reference
    os.remove(CHECK_IPMI_PID)


if __name__ == '__main__':
    gather_metrics()
