#!/usr/bin/env python3
# -*- coding: us-ascii -*-

import re

from nagios_plugin3 import CriticalError, WarnError, try_check

INPUT_FILE = '/var/lib/nagios/sas2ircu.out'


def parse_output():
    enclosure_re = r'^\s+Enclosure #\s+:\s+(\d+)'
    slot_re = r'^\s+Slot #\s+:\s+(\d+)'
    state_re = r'^\s+State\s+:\s+(\S+)'

    encl_slot_state_cre = [
        re.compile(enclosure_re),
        re.compile(slot_re),
        re.compile(state_re),
    ]

    devices = {}
    device = []
    critical = False
    with open(INPUT_FILE) as devices_raw:
        for line in devices_raw.readlines():
            line = line.rstrip()
            for cre in encl_slot_state_cre:
                m = cre.match(line)
                if m:
                    device.append(m.group(1))

            if len(device) == 3:
                tmpdev = devices.get(device[2], [])
                tmpdev.append('{}:{}'.format(device[0], device[1]))
                devices[device[2]] = tmpdev
                if 'Ready' not in device:
                    critical = True
                device = []

    msg = '; '.join([
        '{}[{}]'.format(state, ','.join(devices[state])) for state in devices
    ])
    if msg == '':
        raise WarnError('WARNING: no output')
    elif critical:
        raise CriticalError('CRITICAL: {}'.format(msg))
    else:
        print('OK: {}'.format(msg))


def main():
    try_check(parse_output)


if __name__ == '__main__':
    main()
