# -*- coding: us-ascii -*-
import os
import re
import subprocess

from hwhealth import tools
from hwhealth.discovery.lshw import Hardware
from hwhealth.discovery.supported_vendors import SUPPORTED_VENDORS, SUPPORTED_DRIVERS

from charmhelpers.core import hookenv


def get_tools(manufacturer='auto'):
    if manufacturer == 'test':
        # Return all possible tools to aid testing
        return [
            # tools.HPE(), # NotImplementedYet
            # tools.HP(),  # NotImplementedYet
            tools.Mdadm(),
            tools.MegaCLI(),
            tools.Nvme(),
            tools.Ipmi(),
            #tools.Sas2Ircu(),
            #tools.Sas3Ircu(),
        ]
    elif manufacturer == 'auto':
        return _get_tools()
    else:
        raise NotImplementedError


def _get_tools():
    hwinfo = Hardware()
    toolset = set()
    for storage in hwinfo.get_storage_class_info:
        if storage.get('vendor'):
            if storage.get('product') in SUPPORTED_VENDORS.get(storage['vendor'], []):
                toolset.add(SUPPORTED_VENDORS[storage['vendor']][storage['product']])
            else:
                hookenv.log('Product not supported: [{vendor}][{product}]'.format(**storage),
                            hookenv.DEBUG)

        driver = storage.get('driver')
        if driver:
            if driver in SUPPORTED_DRIVERS:
                toolset.add(SUPPORTED_DRIVERS[driver])
                continue
            hookenv.log('Driver not supported: {}'.format(driver), hookenv.DEBUG)

    # SW RAID?
    if _supports_mdadm():
        toolset.add(tools.Mdadm)

    if hookenv.config('enable_ipmi'):
        toolset.add(tools.Ipmi)

    executed_toolset = set([tool() for tool in toolset])
    return executed_toolset


def _supports_mdadm():
    """scans for mdadm devices and returns True when the first one is found (otherwise, it returns False)
    """
    if os.path.exists('/sbin/mdadm'):
        try:
            devices_raw = subprocess.check_output(['/sbin/mdadm', '--detail', '--scan'])
            devices_re = re.compile(r'^ARRAY\s+(\S+) ')
            for line in devices_raw.splitlines():
                line = line.decode().strip()
                raid_dev = devices_re.search(line)
                if raid_dev:
                    hookenv.log("Found md raid array {}".format(raid_dev.group(1)))
                    return True
        except Exception as e:
            hookenv.log("mdadm scan failed with {}".format(e))
    return False


if __name__ == '__main__':
    toolset = get_tools()
    if not toolset:
        print('No RAID')
    else:
        print(toolset)
