import io
import os
import sys
import unittest
import unittest.mock as mock

import nagios_plugin3

sys.path.append('files/mdadm')
import check_mdadm  # noqa: E402


class TestCheckMdadm(unittest.TestCase):
    def test_parse_output_crit(self):
        check_mdadm.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples',
            'mdadm.output.nrpe.critical')
        expected = 'CRITICAL: critical msg'
        with self.assertRaises(nagios_plugin3.CriticalError) as context:
            check_mdadm.parse_output()
        self.assertTrue(expected in str(context.exception))

    def test_parse_output_warn(self):
        check_mdadm.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples',
            'mdadm.output.nrpe.warning')
        expected = 'WARNING: warning msg'
        with self.assertRaises(nagios_plugin3.WarnError) as context:
            check_mdadm.parse_output()
        self.assertTrue(expected in str(context.exception))

    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output_ok(self, mock_print):
        check_mdadm.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples', 'mdadm.output.nrpe.ok')
        check_mdadm.parse_output()
        self.assertEqual(
            mock_print.getvalue(),
            'OK: /dev/md0 ok; /dev/md1 ok; /dev/md3 ok; /dev/md2 ok\n'
        )

    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output_unknown_filenotfound(self, mock_print):
        check_mdadm.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples',
            'thisfiledoesnotexist')
        expected = 'UNKNOWN: file not found ({})'.format(
            check_mdadm.INPUT_FILE)
        with self.assertRaises(nagios_plugin3.UnknownError) as context:
            check_mdadm.parse_output()
        self.assertTrue(expected in str(context.exception))

    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output_unknown1(self, mock_print):
        check_mdadm.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples',
            'mdadm.output.nrpe.unknown.1')
        check_mdadm.parse_output()
        self.assertEqual(
            mock_print.getvalue(),
            'UNKNOWN: unknown msg\n'
        )

    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output_unknown2(self, mock_print):
        check_mdadm.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples',
            'mdadm.output.nrpe.unknown.2')
        check_mdadm.parse_output()
        self.assertEqual(
            mock_print.getvalue(),
            'unknown msg2\n'
        )
