import io
import os
import sys
import unittest
import unittest.mock as mock

import nagios_plugin3

sys.path.append('files/megacli')
import check_megacli  # noqa: E402


class TestCheckMegaCLI(unittest.TestCase):
    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output(self, mock_print):
        check_megacli.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples', 'megacli.output.1')
        check_megacli.parse_output()
        actual = mock_print.getvalue()
        expected = 'OK: Optimal, ldrives[1], pdrives[4]\n'
        self.assertEqual(actual, expected)

    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output_critical_singledrive(self, mock_print):
        check_megacli.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples', 'megacli.output.nrpe.critical.1')
        expected = 'CRITICAL: adapter(0):ld(0):state(Degraded)'
        with self.assertRaises(nagios_plugin3.CriticalError) as context:
            check_megacli.parse_output()
        self.assertEqual(expected, str(context.exception))

    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output_critical_multiple(self, mock_print):
        check_megacli.INPUT_FILE = os.path.join(
            os.getcwd(), 'tests', 'hw-health-samples', 'megacli.output.nrpe.critical.2')
        expected = ('CRITICAL: adapter(0):ld(0):state(Degraded);'
                    ' adapter(0):ld(4):state(Degraded)')
        with self.assertRaises(nagios_plugin3.CriticalError) as context:
            check_megacli.parse_output()
        self.assertEqual(expected, str(context.exception))
