import io
import os
import sys
import unittest
import unittest.mock as mock

sys.path.append('files/nvme')
import check_nvme  # noqa: E402


class TestCheckNvme(unittest.TestCase):
    @mock.patch('check_nvme.glob.glob')
    @mock.patch('check_nvme.subprocess.check_output')
    @mock.patch('sys.stdout', new_callable=io.StringIO)
    def test_parse_output(self, mock_print, mock_subprocess, mock_glob):
        mock_glob.return_value = ['/dev/nvme0']
        input_file = os.path.join(os.getcwd(), 'tests', 'hw-health-samples',
                                  'nvme.output.1')
        with open(input_file, 'r') as fd:
            mock_subprocess.return_value = fd.read().encode()
        check_nvme.parse_output()
        expected = (
            "OK: no errors on /dev/nvme0 | 'critical_warning'=0"
            " 'temperature'=31 'available_spare'=100"
            " 'available_spare_threshold'=50 'percentage_used'=1"
            " 'data_units_read'=1329669 'data_units_written'=11064455"
            " 'host_read_commands'=21631751 'host_write_commands'=295816770"
            " 'controller_busy_time'=847 'power_cycles'=679"
            " 'power_on_hours'=1561 'unsafe_shutdowns'=36 'media_errors'=0"
            " 'num_err_log_entries'=20\n"
        )
        self.maxDiff = None
        self.assertEqual(mock_print.getvalue(), expected)
